@@ -33,10 +33,9 @@ from .xmlapi import XMLAPI
 
 class VeracodeAPI:
 
-    def __init__(self, proxies=None):
+    def __init__(self):
         self.baseurl = 'https://analysiscenter.veracode.com/api'
         requests.Session().mount(self.baseurl, HTTPAdapter(max_retries=3))
-        self.proxies = proxies
         self.retry_seconds = 120
         self.connect_error_msg = "Connection Error"
 
@@ -296,6 +295,9 @@ class VeracodeAPI:
     def add_workspace_team(self, workspace_guid: UUID, team_id: UUID):
         return Workspaces().add_team(workspace_guid, team_id)
 
+    def remove_workspace_team(self, workspace_guid: UUID, team_id: UUID):
+        return Workspaces().remove_team(workspace_guid, team_id)
+        
     def get_workspace_teams(self, workspace_guid: UUID=None):
         return Workspaces().get_teams(workspace_guid=workspace_guid)
 
